import re

# examples of real DOIs: 
#         10.1002/(SICI)1098-1004(1999)14:1<91::AID-HUMU21>3.0.CO;2-B

re_doi = re.compile(r'(10[.][0-9]{2,}(?:[.][0-9]+)*/(?:(?!["&\'])\S)+)')

def findall_dois_in_text(body):
    return re_doi.findall(body)

def find_doi_in_string(body):
    try:
        return re_doi.findall(body)[0]
    except IndexError:
        return None




from __future__ import absolute_import

from pkgutil import extend_path
__path__ = extend_path(__path__, __name__)

from .pubmedarticle import PubMedArticle
from .pubmedfetcher import PubMedFetcher
from .medgenfetcher import MedGenFetcher
from .medgenconcept import MedGenConcept
from .crossref import CrossRef

